CREATE PROCEDURE [dbo].[GetFormattedNames] 
@strObjSchema varchar ( 50 ) , 
@strObjName varchar ( 50 ) , 
@strObjType varchar ( 50 ) , 
@strFormat varchar ( 50 ) , 
@isBracketed bit = 0 , 
@isGetSampleData bit = 0 , 
@isUseQuery bit = 0 , 
@strQuery nvarchar ( max ) = NULL 

/*
ObjTypes: 
TABLE
VIEW
PROCEDURE

Table/View Formats: 
NAME
VARIABLE
VARIABLE_AS_COLS
VARIABLE_EQ_COLS
VARIABLE_DATATYPE_WITH_DEFAULTS
DECLARE
DECLARE_NULLABLE
UPDATE
MERGE_UPDATE
TEST_PARAMETERS_UNPOPULATED
TEST_PARAMETERS_POPULATED    

Procedure Formats: 
NAME
VARIABLE
DECLARE
TEST_PARAMETERS_UNPOPULATED
TEST_PARAMETERS_POPULATED    

*/ 
AS 
BEGIN 

    SET NOCOUNT ON 

    DECLARE 
    @strDelimiter varchar ( 10 ) , @strDataType varchar ( 50 ) , @strDataLength varchar ( 50 ) , @strLineBreak varchar ( 10 ) , @strCols varchar ( max ) , @strSQL varchar ( max ) , @strBL varchar ( 1 ) , @strBR varchar ( 1 ) , @strCount nvarchar ( max ) , @strColName nvarchar ( 100 ) , @intTempVar int 
    , @x int 

    IF object_id ( 'tempdb..##TempTable' ) IS NOT NULL 
    DROP TABLE ##TempTable 

    CREATE TABLE ##TempTable 
    ( 
        [ID] int NOT NULL , 
        [OBJ_NAME] nvarchar ( 50 ) NULL , 
        [DATA_TYPE] nvarchar ( 50 ) NULL , 
        [DATA_LENGTH] nvarchar ( 50 ) NULL , 
        [COLUMN_DEFAULT] nvarchar ( 50 ) NULL , 
        [IS_NULLABLE] nvarchar ( 50 ) NULL , 
        [IS_IDENTITY] bit NULL , 
        [COLUMN_VALUE] nvarchar ( max ) , 
        PRIMARY KEY ( ID ) ) 

    IF @isBracketed = 1 
    BEGIN 
        SET @strBL = '[' 
        SET @strBR = ']' 
    END 
    ELSE 
    BEGIN 
        SET @strBL = '' 
        SET @strBR = '' 
    END 

    IF @isUseQuery <> 1 
    SET @isUseQuery = 0 

    IF nullif ( @strQuery , '' ) IS NULL 
    SET @isUseQuery = 0 

    SET @strDelimiter = ',' 
    SET @strLineBreak = char ( 13 ) + char ( 10 ) 

    /* If populate with query option has been chosen validate the query. */ 

    SET @strCount = '' 
    SET @x = 0 

    IF @isUseQuery = 1 
    BEGIN 
        TRY 

        SET @strCount = N'SELECT @intTempVar = (SELECT COUNT(*) FROM (' + @strQuery + ') AS r)' 

        EXEC sp_executesql @strCount , N'@intTempVar INT OUTPUT' , @x OUTPUT 

    END 
    TRY 
    BEGIN 
        CATCH 
        RETURN --invalid query
    END 
    CATCH 

    /* Populate a temp table with the query results */ 

    IF @isUseQuery = 1 
    BEGIN 

        SELECT @x = count ( * ) FROM INFORMATION_SCHEMA.VIEWS 
        WHERE TABLE_SCHEMA = 'dbo' 
        AND TABLE_NAME = 'vwQueryResults' 

        IF @x > 0 
        DROP VIEW dbo.vwQueryResults 

        SET @strQuery = N'CREATE VIEW dbo.vwQueryResults AS ' + @strQuery 

        EXEC ( @strQuery ) 

        SET @strObjSchema = 'dbo' 
        SET @strObjName = 'vwQueryResults' 
        SET @strObjType = 'VIEW' 

    END 

    IF @strObjType IN ( 'TABLE' , 'VIEW' ) 
    BEGIN 

        SET @strSQL = '
        INSERT INTO ##TempTable
        SELECT 
        iscol.ORDINAL_POSITION AS ID
        ,iscol.COLUMN_NAME
        ,iscol.DATA_TYPE
        ,(CASE
        WHEN (iscol.DATA_TYPE IN (''char'',''varchar'',''nchar'',''nvarchar'')
        AND iscol.CHARACTER_OCTET_LENGTH = -1)
        THEN ''(MAX)''
        WHEN iscol.DATA_TYPE IN (''char'',''varchar'')  
        THEN ''(''+CAST(iscol.CHARACTER_OCTET_LENGTH AS VARCHAR)+'')''
        WHEN iscol.DATA_TYPE IN (''nchar'',''nvarchar'') 
        THEN ''(''+CAST(iscol.CHARACTER_OCTET_LENGTH/2 AS VARCHAR)+'')''
        WHEN iscol.DATA_TYPE = ''decimal'' 
        THEN ''(''+CAST(iscol.NUMERIC_PRECISION AS VARCHAR)+'',''+CAST(iscol.NUMERIC_SCALE AS VARCHAR)+'')''
        ELSE ''''
        END) AS DATA_LENGTH   
        ,iscol.COLUMN_DEFAULT    
        ,(CASE
        WHEN iscol.IS_NULLABLE = ''YES'' THEN ''NULL''
        ELSE ''NOT NULL''
        END) AS IS_NULLABLE
        ,COLUMNPROPERTY(OBJECT_ID(''' + @strObjSchema + '.' + @strObjName + '''),iscol.COLUMN_NAME,''IsIdentity'') AS IS_IDENTITY
        ,NULL AS COLUMN_VALUE
        FROM
        INFORMATION_SCHEMA.COLUMNS AS iscol
        WHERE
        iscol.TABLE_SCHEMA = ''' + @strObjSchema + '''
        AND iscol.TABLE_NAME = ''' + @strObjName + '''
        ORDER BY
        iscol.ORDINAL_POSITION' 

    END 
    ELSE IF @strObjType = 'PROCEDURE' 
    BEGIN 

        SET @strSQL = '
        INSERT INTO ##TempTable
        SELECT 
        iscol.ORDINAL_POSITION AS ID
        ,iscol.PARAMETER_NAME
        ,iscol.DATA_TYPE
        ,(CASE
        WHEN (iscol.DATA_TYPE IN (''char'',''varchar'',''nchar'',''nvarchar'')
        AND iscol.CHARACTER_OCTET_LENGTH = -1)
        THEN ''(MAX)''
        WHEN iscol.DATA_TYPE IN (''char'',''varchar'')  
        THEN ''(''+CAST(iscol.CHARACTER_OCTET_LENGTH AS VARCHAR)+'')''
        WHEN iscol.DATA_TYPE IN (''nchar'',''nvarchar'') 
        THEN ''(''+CAST(iscol.CHARACTER_OCTET_LENGTH/2 AS VARCHAR)+'')''
        WHEN iscol.DATA_TYPE = ''decimal'' 
        THEN ''(''+CAST(iscol.NUMERIC_PRECISION AS VARCHAR)+'',''+CAST(iscol.NUMERIC_SCALE AS VARCHAR)+'')''
        ELSE ''''
        END) AS DATA_LENGTH 
        ,NULL AS COLUMN_DEFAULT
        ,NULL AS IS_NULLABLE
        ,NULL AS IS_IDENTITY
        ,NULL AS COLUMN_VALUE
        FROM
        INFORMATION_SCHEMA.PARAMETERS AS iscol
        WHERE
        iscol.SPECIFIC_SCHEMA = ''' + @strObjSchema + '''
        AND iscol.SPECIFIC_NAME = ''' + @strObjName + '''
        ORDER BY
        iscol.ORDINAL_POSITION' 
    END 
    ELSE 
    BEGIN 
        PRINT 'INVALID OBJECT TYPE' 
        RETURN 
    END 

    /* Populate the temp table */ 

    EXEC ( @strSQL ) 

    /* Get some sample values */ 

    IF @isGetSampleData = 1 AND @strObjType IN ( 'TABLE' , 'VIEW' ) 
    BEGIN 

        DECLARE UpdateList CURSOR 
        FOR 
        SELECT 
        ID , 
        OBJ_NAME 
        FROM ##TempTable 
        ORDER BY 
        ID 

        OPEN UpdateList 
        FETCH NEXT FROM UpdateList INTO 
        @x 
        , @strColName 

        WHILE @@FETCH_STATUS = 0 
        BEGIN 

            SET @strSQL = 
            'UPDATE ##TempTable 
            SET COLUMN_VALUE =
            (
            SELECT TOP(1) ' + @strColName + ' 
            FROM ' + @strObjSchema + '.' + @strObjName + '
            )
            WHERE ID = ' + cast ( @x AS varchar ( 3 ) ) 

            EXEC ( @strSQL ) 

            FETCH NEXT FROM UpdateList INTO 
            @x 
            , @strColName 

        END 

        CLOSE UpdateList 
        DEALLOCATE UpdateList 

    END 

    /* Rearrange the data based on specified format */ 

    IF @strFormat IN 
    ( 
        'TEST_PARAMETERS_UNPOPULATED' 
        , 'TEST_PARAMETERS_POPULATED' 
    ) 
    BEGIN 
        UPDATE ##TempTable 
        SET OBJ_NAME = '' 
    END 

    IF @strObjType IN ( 'TABLE' , 'VIEW' ) 
    BEGIN 

        IF @strFormat IN 
        ( 
            'VARIABLE' 
            , 'VARIABLE_AS_COLS' 
            , 'VARIABLE_EQ_COLS' 
            , 'VARIABLE_DATATYPE_WITH_DEFAULTS' 
            , 'DECLARE' 
            , 'DECLARE_NULLABLE' 
        ) 
        SET @strDelimiter = ',@' 

        SELECT 
        @strCols = coalesce ( @strCols + @strLineBreak + @strDelimiter , '' ) + 
        CASE 
            WHEN @strFormat IN 
            ( 
                'VARIABLE' 
                , 'VARIABLE_DATATYPE_WITH_DEFAULTS' 
                , 'DECLARE' 
                , 'DECLARE_NULLABLE' 
                , 'TEST_PARAMETERS_POPULATED' 
                , 'TEST_PARAMETERS_UNPOPULATED' 
            ) 
            THEN cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) 
            WHEN @strFormat IN ( 'VARIABLE_AS_COLS' ) THEN cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) + ' AS ' + @strBL + cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) + @strBR 
            WHEN @strFormat IN ( 'VARIABLE_EQ_COLS' ) THEN cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) + ' = ' + @strBL + cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) + @strBR 
            WHEN @strFormat IN ( 'UPDATE' ) THEN @strBL + cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) + @strBR + ' = @' + cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) 
            WHEN @strFormat IN ( 'MERGE_UPDATE' ) THEN @strBL + 'Target' + @strBR + '.' + @strBL + cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) + @strBR + ' = @' + cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) 
            ELSE @strBL + cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) + @strBR 
        END + 
        CASE 
            WHEN @strFormat IN 
            ( 
                'DECLARE' 
                , 'VARIABLE_DATATYPE_WITH_DEFAULTS' 
            ) 
            THEN ' ' + @strBL + upper ( cast ( tt.DATA_TYPE AS nvarchar ( 255 ) ) ) + @strBR + upper ( cast ( tt.DATA_LENGTH AS nvarchar ( 255 ) ) ) + CASE 
            WHEN @strFormat IN ( 'DECLARE' ) AND tt.IS_IDENTITY = 1 THEN ' IDENTITY(1,1)' 
            ELSE '' 
        END 
        WHEN @strFormat IN ( 'DECLARE_NULLABLE' ) THEN ' ' + @strBL + upper ( cast ( tt.DATA_TYPE AS nvarchar ( 255 ) ) ) + @strBR + upper ( cast ( tt.DATA_LENGTH AS nvarchar ( 255 ) ) ) + 
        CASE 
            WHEN tt.IS_IDENTITY = 1 THEN ' IDENTITY(1,1)' 
            ELSE '' 
        END + ' ' + upper ( cast ( tt.IS_NULLABLE AS nvarchar ( 255 ) ) ) 

        ELSE '' 
    END + 
    CASE 
        WHEN @strFormat = 'VARIABLE_DATATYPE_WITH_DEFAULTS' AND ( tt.DATA_TYPE IN ( 'CHAR' , 'VARCHAR' , 'NCHAR' , 'NVARCHAR' ) ) THEN ' = ' + CASE 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE '''''' 
    END 
    WHEN @strFormat = 'VARIABLE_DATATYPE_WITH_DEFAULTS' 
    AND tt.DATA_TYPE = 'DATETIME' 
    THEN ' = ' + 
    CASE 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE 'NULL' 
    END 
    WHEN @strFormat = 'VARIABLE_DATATYPE_WITH_DEFAULTS' 
    THEN ' = ' + 
    CASE 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE '0' 
    END 
    WHEN @strFormat = 'TEST_PARAMETERS_UNPOPULATED' 
    AND ( tt.DATA_TYPE IN ( 'CHAR' , 'VARCHAR' , 'NCHAR' , 'NVARCHAR' ) ) 
    THEN '''''' 
    WHEN @strFormat = 'TEST_PARAMETERS_UNPOPULATED' 
    AND tt.DATA_TYPE = 'DATETIME' 
    THEN 'NULL' 
    WHEN @strFormat = 'TEST_PARAMETERS_UNPOPULATED' 
    THEN '0' 
    WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' 
    AND ( tt.DATA_TYPE IN ( 'CHAR' , 'VARCHAR' , 'NCHAR' , 'NVARCHAR' ) ) 
    THEN '''' + 
    CASE 
        WHEN @isGetSampleData = 1 THEN tt.COLUMN_VALUE 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE 'AbcXyz' 
    END + '''' 
    WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' 
    AND tt.DATA_TYPE = 'DATETIME' 
    THEN '''' + 
    CASE 
        WHEN @isGetSampleData = 1 THEN convert ( varchar ( 19 ) , cast ( tt.COLUMN_VALUE AS datetime ) , 120 ) 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE convert ( varchar ( 19 ) , cast ( getdate ( ) AS datetime ) , 120 ) 
    END + '''' 
    WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' 
    AND tt.DATA_TYPE = 'BIT' 
    THEN 
    CASE 
        WHEN @isGetSampleData = 1 THEN tt.COLUMN_VALUE 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE '0' 
    END 
    WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' 
    AND tt.DATA_TYPE = 'UNIQUEIDENTIFIER' 
    THEN 
    CASE 
        WHEN @isGetSampleData = 1 THEN tt.COLUMN_VALUE 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE '''' + ( cast ( newid ( ) AS varchar ( 36 ) ) ) + '''' 
    END 
    WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' 
    THEN 
    CASE 
        WHEN @isGetSampleData = 1 THEN tt.COLUMN_VALUE 
        WHEN tt.COLUMN_DEFAULT IS NOT NULL THEN upper ( tt.COLUMN_DEFAULT ) 
        ELSE '123' 
    END 
    ELSE '' 
END 
FROM 
##TempTable AS tt 

END 
ELSE IF @strObjType = 'PROCEDURE' 
BEGIN 

    SELECT 
    @strCols = coalesce ( @strCols + @strLineBreak + @strDelimiter , '' ) + 
    CASE 
        WHEN @strFormat IN 
        ( 
            'VARIABLE' 
            , 'DECLARE' 
            , 'TEST_PARAMETERS_POPULATED' 
            , 'TEST_PARAMETERS_UNPOPULATED' 
        ) 
        THEN cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) 
        ELSE @strBL + replace ( cast ( tt.OBJ_NAME AS nvarchar ( 255 ) ) , '@' , '' ) + @strBR 
    END + 
    CASE 
        WHEN @strFormat IN ( 'DECLARE' ) THEN ' ' + @strBL + upper ( cast ( tt.DATA_TYPE AS nvarchar ( 255 ) ) ) + @strBR + upper ( cast ( tt.DATA_LENGTH AS nvarchar ( 255 ) ) ) 
        ELSE '' 
    END + 
    CASE 
        WHEN @strFormat = 'TEST_PARAMETERS_UNPOPULATED' AND ( tt.DATA_TYPE IN ( 'CHAR' , 'VARCHAR' , 'NCHAR' , 'NVARCHAR' ) ) THEN '''''' 
        WHEN @strFormat = 'TEST_PARAMETERS_UNPOPULATED' AND tt.DATA_TYPE = 'DATETIME' THEN 'NULL' 
        WHEN @strFormat = 'TEST_PARAMETERS_UNPOPULATED' THEN '0' 
        WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' AND ( tt.DATA_TYPE IN ( 'CHAR' , 'VARCHAR' , 'NCHAR' , 'NVARCHAR' ) ) THEN '''AbcXyz''' 
        WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' AND tt.DATA_TYPE = 'DATETIME' THEN '''' + ( convert ( varchar ( 19 ) , cast ( getdate ( ) AS datetime ) , 120 ) ) + '''' 
        WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' AND tt.DATA_TYPE = 'BIT' THEN '0' 
        WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' AND tt.DATA_TYPE = 'UNIQUEIDENTIFIER' THEN '''' + ( cast ( newid ( ) AS varchar ( 36 ) ) ) + '''' 
        WHEN @strFormat = 'TEST_PARAMETERS_POPULATED' THEN '123' 
        ELSE '' 
    END 
    FROM ##TempTable AS tt 

END 

/* Print the results */ 

PRINT @strObjType + ' ' + @strObjSchema + '.' + @strObjName 
PRINT 'Format: ' + @strFormat 

SET @strCols = replace ( @strCols , '(GETDATE())' , 'GETDATE()' ) 
SET @strCols = replace ( replace ( @strCols , '((' , '' ) , '))' , '' ) 

IF @strObjType IN ( 'TABLE' , 'VIEW' ) 
AND @strFormat IN 
( 
    'VARIABLE' 
    , 'VARIABLE_AS_COLS' 
    , 'VARIABLE_EQ_COLS' 
    , 'VARIABLE_DATATYPE_WITH_DEFAULTS' 
    , 'DECLARE' 
    , 'DECLARE_NULLABLE' 
) 
PRINT ' @' + @strCols + @strLineBreak + @strLineBreak 
ELSE 
PRINT ' ' + @strCols + @strLineBreak + @strLineBreak 

/* Clean up */ 

SELECT @x = count ( * ) FROM INFORMATION_SCHEMA.VIEWS 
WHERE TABLE_SCHEMA = 'dbo' 
AND TABLE_NAME = 'vwQueryResults' 

IF @x > 0 
DROP VIEW dbo.vwQueryResults 

IF object_id ( 'tempdb..##TempTable' ) IS NOT NULL 
DROP TABLE ##TempTable 

/*
Examples:

EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','NAME',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','VARIABLE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','VARIABLE_AS_COLS',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','VARIABLE_EQ_COLS',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','VARIABLE_DATATYPE_WITH_DEFAULTS',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','DECLARE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','DECLARE_NULLABLE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','UPDATE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','MERGE_UPDATE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_UNPOPULATED',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',1,0,0,NULL

EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','NAME',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','VARIABLE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','VARIABLE_AS_COLS',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','VARIABLE_EQ_COLS',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','VARIABLE_DATATYPE_WITH_DEFAULTS',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','DECLARE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','DECLARE_NULLABLE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','UPDATE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','MERGE_UPDATE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','TEST_PARAMETERS_UNPOPULATED',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','vwTestContacts','VIEW','TEST_PARAMETERS_POPULATED',1,0,0,NULL

EXEC dbo.GetFormattedNames 'dbo','TestAddContact','PROCEDURE','NAME',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestAddContact','PROCEDURE','VARIABLE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestAddContact','PROCEDURE','DECLARE',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestAddContact','PROCEDURE','TEST_PARAMETERS_UNPOPULATED',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestAddContact','PROCEDURE','TEST_PARAMETERS_POPULATED',1,0,0,NULL

EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',0,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',1,0,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',0,1,0,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',0,0,1,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',1,0,1,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',0,1,1,NULL
EXEC dbo.GetFormattedNames 'dbo','TestContact','TABLE','TEST_PARAMETERS_POPULATED',0,1,1
,'SELECT FName, LName, isActive, dateCreated, sortOrder FROM dbo.TestContact'


*/ 

/*
--For testing only

CREATE TABLE [dbo].[TestContact](
[ContactID] [int] IDENTITY(1,1) NOT NULL,
[FName] [nvarchar](50) NULL,
[LName] [nvarchar](50) NULL,
[Address1] [nvarchar](50) NULL,
[Address2] [nvarchar](50) NULL,
[City] [nvarchar](50) NULL,
[State] [nvarchar](50) NULL,
[Zip] [nvarchar](50) NULL,
[Phone] [nvarchar](50) NULL,
[Email] [nvarchar](50) NULL,
[isActive] [bit] NOT NULL,
[dateCreated] [datetime] NOT NULL,
[sortOrder] [int] NOT NULL,
CONSTRAINT [PK_TestContact] PRIMARY KEY CLUSTERED 
(
[ContactID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

ALTER TABLE [dbo].[TestContact] ADD  CONSTRAINT [DF_isActive]  DEFAULT ((0)) FOR [isActive]
GO

ALTER TABLE [dbo].[TestContact] ADD  CONSTRAINT [DF_dateCreated]  DEFAULT (GETDATE()) FOR [dateCreated]
GO

ALTER TABLE [dbo].[TestContact] ADD  CONSTRAINT [DF_sortOrder]  DEFAULT ((9999)) FOR [sortOrder]
GO


CREATE VIEW [dbo].[vwTestContacts]
AS
SELECT
FName
,LName
,Address1
,Address2
,City
,State
,Zip
FROM
dbo.TestContact
GO



CREATE PROCEDURE [dbo].[TestAddContact]

@FName NVARCHAR(50)
,@LName NVARCHAR(50)
,@Address1 NVARCHAR(50)
,@Address2 NVARCHAR(50)
,@City NVARCHAR(50)
,@State NVARCHAR(50)
,@Zip NVARCHAR(50)
,@Phone NVARCHAR(50)
,@Email NVARCHAR(50)
,@isActive BIT
,@dateCreated DATETIME
,@sortOrder INT

AS 
BEGIN

DECLARE @ContactID INT

INSERT INTO dbo.TestContact
(
FName
,LName
,Address1
,Address2
,City
,State
,Zip
,Phone
,Email
,isActive
,dateCreated
,sortOrder
)
VALUES
(
@FName
,@LName
,@Address1
,@Address2
,@City
,@State
,@Zip
,@Phone
,@Email
,@isActive
,GETDATE()
,@sortOrder
)

SELECT
@ContactID = SCOPE_IDENTITY()

END
GO


-- Create a test entry 

EXEC [dbo].[TestAddContact]
'George'
,'Washington'
,'123 Apple Blossom Lane'
,NULL
,'Mt. Vernon'
,'VA'
,'21345'
,'555-567-2345'
,'test@aol.com'
,1
,'2013-01-18 18:54:28.203'
,100
GO

*/ 

END